@@ -10,9 +10,15 @@ from reliability import Repairable_systems
 from reliability import Probability_plotting
 from reliability import Datasets
 from reliability import ALT_fitters
-from reliability import ALT_probability_plotting
 from reliability import PoF
 from reliability import Utils
 from reliability import Convert_data
 
-__version__ = "0.5.6"  # Current version
+__title__ = 'reliability'
+__version__ = "0.6.0"
+__description__ = 'A Python library for reliability engineering'
+__url__ = 'https://reliability.readthedocs.io/en/latest/index.html'
+__author__ = 'Matthew Reid'
+__author_email__ = 'alpha.reliability@gmail.com'
+__license__ = 'LGPLv3'
+__copyright__ = 'Copyright 2019-2021 Matthew Reid'
